@@ -1,4 +1,4 @@
-setupLambda <- function(X,y,group,family,J,K,penalty,lambda.max,lambda.min,n.lambda,a,gamma)
+setupLambda <- function(X,y,group,family,J,K,penalty,lambda.max,lambda.min,nlambda,gamma)
   {
     if (missing(lambda.max))
       {
@@ -15,10 +15,10 @@ setupLambda <- function(X,y,group,family,J,K,penalty,lambda.max,lambda.min,n.lam
             w <- sqrt(pi.*(1-pi.))
             r = (y - pi.)/w;
           }
-        lambda.max <- .C("determineMax",double(1),as.double(X[,group!=0]),as.double(r),as.double(w),as.integer(group),family,as.integer(length(y)),as.integer(sum(group!=0)),as.integer(J),as.integer(K),penalty,gamma,a)[[1]] + 1e-6
+        lambda.max <- .C("determineMax",double(1),as.double(X[,group!=0]),as.double(r),as.double(w),as.integer(group),family,as.integer(length(y)),as.integer(sum(group!=0)),as.integer(J),as.integer(K),penalty,gamma)[[1]] + 1e-6
       }
-    if (lambda.min==0) lambda <- c(exp(seq(log(lambda.max),log(.001*lambda.max),len=n.lambda-1)),0)
-    else lambda <- exp(seq(log(lambda.max),log(lambda.min*lambda.max),len=n.lambda))
+    if (lambda.min==0) lambda <- c(exp(seq(log(lambda.max),log(.001*lambda.max),len=nlambda-1)),0)
+    else lambda <- exp(seq(log(lambda.max),log(lambda.min*lambda.max),len=nlambda))
     if (penalty=="gBridge") lambda <- rev(lambda)
     return(lambda)
   }
